﻿using Kivii.DataAnnotations;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.Lims.ExcelToPdf.Requests
{
    [Route(Configs.RoutePrintPoolCreate)]
    public class PrintPoolRequest : IReturn<PrintPoolCreateResponse>
    {
        public string EntityType { get; set; } = "Kivii.Lims.Entities.Report";
        public PrintPool Item { get; set; }
    }

    public class PrintPoolCreateResponse : RestfulCreateResponse<PrintPool> { }

    public class PrintPool : EntityWithMetadata
    {
        #region 关联相关
        [IgnoreUpdate]
        [Required]
        public Guid OwnerKvid { get; set; }

        [StringLength(500)]
        public string OwnerName { get; set; }
        #endregion

        [ApiMember(Description = "打印标题")]
        [IgnoreUpdate]
        [StringLength(100), Required]
        public string Title { get; set; }

        [ApiMember(Description = "打印分类")]
        [InternalSetter]
        [StringLength(50), Default("")]
        public string Category { get; set; }

        [ApiMember(Description = "是否打印")]
        [InternalSetter]
        public bool IsPrint { get; set; }

        [ApiMember(Description = "打印份数,默认0份")]
        [Default(0)]
        public int Count { get; set; }

        [ApiMember(Description = "打印时间")]
        [InternalSetter]
        public DateTime? PrintTime { get; set; }

        [ApiMember(Description = "打印结果")]
        [InternalSetter]
        [StringLength(500), Default("")]
        public string Result { get; set; }

        [ApiMember(Description = "文件地址,要打印的文件地址")]
        [StringLength(1000), Required]
        public string FilePath { get; set; }

        #region 文本 摘要 备注
        [ApiMember(Description = "摘要，最大500字")]
        [IgnoreUpdate]
        [StringLength(500), Default("")]
        public string Summary { get; set; }

        [ApiMember(Description = "备注，最大3000字")]
        [StringLength(3000), Default("")]
        public string Remark { get; set; }
        #endregion

        [ApiMember(Description = "操作日期")]
        [IgnoreUpdate]
        [Required]
        public DateTime OperateTime { get; set; }

        [InternalSetter]
        [DefaultEmptyGuid]
        public Guid OperatorKvid { get; set; }

        [ApiMember(Description = "操作人")]
        [InternalSetter]
        [StringLength(100), Default("")]
        public string OperatorName { get; set; }


        [ApiMember(Description = "创建人Kvid ")]
        [IgnoreUpdate]
        [CurrentMemberKvid]
        public Guid CreatorKvid { get; set; }

        [ApiMember(Description = "创建人")]
        [IgnoreUpdate]
        [StringLength(50), CurrentMemberName]
        public string CreatorName { get; set; }

        [ApiMember(Description = "更新人Kvid ")]
        [CurrentMemberKvid]
        public Guid UpdaterKvid { get; set; }

        [ApiMember(Description = "更新人")]
        [StringLength(50), CurrentMemberName]
        public string UpdaterName { get; set; }
    }
}
